==> arquillian-container-spi-1.6.0.Final-sources.jar: org/jboss/arquillian/container/spi/Container.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2011 Red Hat Inc. and/or its affiliates and other contributors
 * as indicated by the @authors tag. All rights reserved.
 * See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,  
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.arquillian.container.spi;

import org.jboss.arquillian.config.descriptor.api.ContainerDef;
import org.jboss.arquillian.config.descriptor.api.ProtocolDef;
import org.jboss.arquillian.container.spi.client.container.ContainerConfiguration;
import org.jboss.arquillian.container.spi.client.container.DeployableContainer;
import org.jboss.arquillian.container.spi.client.container.LifecycleException;
import org.jboss.arquillian.container.spi.client.protocol.ProtocolDescription;

/**
 * ContainerT
 *
 * @author <a href="mailto:aslak@redhat.com">Aslak Knutsen</a>
 * @version $Revision: $
 */
public interface Container {

    /**
     * @return the name
     */
    String getName();

    /**
     * @return the deployableContainer
     */
    DeployableContainer<?> getDeployableContainer();

    /**
     * @return the containerConfiguration
     */
    ContainerDef getContainerConfiguration();

    /**
     * @return the configuration
     */
    ContainerConfiguration createDeployableConfiguration() throws Exception;

    boolean hasProtocolConfiguration(ProtocolDescription description);

    ProtocolDef getProtocolConfiguration(ProtocolDescription description);

    void setup() throws Exception;

    void start() throws LifecycleException;

    void stop() throws LifecycleException;

    void kill() throws Exception;

    State getState();

    void setState(State state);

    Throwable getFailureCause();

    enum State {
        SETUP, SETUP_FAILED, STARTED, STARTED_FAILED, STOPPED, STOPPED_FAILED, KILLED, KILLED_FAILED;
    }
}

==> arquillian-container-spi-1.9.3.Final-sources.jar: org/jboss/arquillian/container/spi/Container.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2011 Red Hat Inc. and/or its affiliates and other contributors
 * as indicated by the @authors tag. All rights reserved.
 * See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.arquillian.container.spi;

import org.jboss.arquillian.config.descriptor.api.ContainerDef;
import org.jboss.arquillian.config.descriptor.api.ProtocolDef;
import org.jboss.arquillian.container.spi.client.container.ContainerConfiguration;
import org.jboss.arquillian.container.spi.client.container.DeployableContainer;
import org.jboss.arquillian.container.spi.client.container.LifecycleException;
import org.jboss.arquillian.container.spi.client.protocol.ProtocolDescription;

/**
 * ContainerT
 *
 * @author <a href="mailto:aslak@redhat.com">Aslak Knutsen</a>
 * @version $Revision: $
 */
public interface Container<T extends ContainerConfiguration> {

    /**
     * @return the name
     */
    String getName();

    /**
     * @return the deployableContainer
     */
    DeployableContainer<T> getDeployableContainer();

    /**
     * @return the containerConfiguration
     */
    ContainerDef getContainerConfiguration();

    /**
     * @return the configuration
     */
    T createDeployableConfiguration() throws Exception;

    boolean hasProtocolConfiguration(ProtocolDescription description);

    ProtocolDef getProtocolConfiguration(ProtocolDescription description);

    void setup() throws Exception;

    void start() throws LifecycleException;

    void stop() throws LifecycleException;

    void kill() throws Exception;

    State getState();

    void setState(State state);

    Throwable getFailureCause();

    enum State {
        SETUP, SETUP_FAILED, STARTED, STARTED_FAILED, STOPPED, STOPPED_FAILED, KILLED, KILLED_FAILED;
    }
}
